@@ -26,6 +26,6 @@ from mailslurp_client.api.sent_emails_controller_api import SentEmailsController
 from mailslurp_client.api.sms_controller_api import SmsControllerApi
 from mailslurp_client.api.template_controller_api import TemplateControllerApi
 from mailslurp_client.api.tracking_controller_api import TrackingControllerApi
+from mailslurp_client.api.user_controller_api import UserControllerApi
 from mailslurp_client.api.wait_for_controller_api import WaitForControllerApi
 from mailslurp_client.api.webhook_controller_api import WebhookControllerApi
-from mailslurp_client.api.api_user_controller_api import ApiUserControllerApi
